# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .types import (
        ActionType,
        ActivitySchema,
        Actor,
        ActorIdentity,
        ActorIdentityId,
        ActorIdentityType,
        AgentHook,
        AgentHookInput,
        AgentRevision,
        AgentRevisionModel,
        AgentRevisionResponseStyle,
        AgentRevisionToolConfigValue,
        AgentTargetConfig,
        AiAgent,
        ApiKeyAuthType,
        ApiKeyIdentity,
        ApiKeyIdentityDetails,
        AutomationHook,
        AutomationHookInput,
        AutomationTargetConfig,
        BareInput,
        BareOutput,
        Baseline,
        BatchCreateRequest,
        BatchGenerateRequest,
        Billing,
        BillingCycle,
        BillingCycles,
        BillingLimits,
        BillingUsage,
        BlockConfigItemBoolean,
        BlockConfigItemJson,
        BlockConfigItemLlm,
        BlockConfigItemNumber,
        BlockConfigItemNumberDefaultValue,
        BlockConfigItemNumberMaximumValue,
        BlockConfigItemNumberMinimumValue,
        BlockConfigItemNumberValue,
        BlockConfigItemSelect,
        BlockConfigItemTextLong,
        BlockConfigItemTextLongValue,
        BlockConfigItemTextShort,
        BlockInput,
        BlockInputBlockConfigItem,
        BlockOutput,
        BlockOutputBlockConfigItem,
        BlockRun,
        BlockRunCompleted,
        BlockRunCompletedData,
        BlockRunCompletedEnvironment,
        BlockRunFailed,
        BlockRunFailedData,
        BlockRunFailedEnvironment,
        BlockRunStarted,
        BlockRunStartedData,
        BlockRunStartedEnvironment,
        BlockRunUsage,
        BlockStateUpdated,
        BlockStateUpdatedData,
        BlockStateUpdatedDataUpdateType,
        BlockStateUpdatedEnvironment,
        BodyParseFileV2FilesParsePost,
        BodyUploadFilesToDriveDriveFilesPost,
        BodyUploadPrivateFilesInboxSessionIdFilesPost,
        BodyUploadPulseFilesStreamPulseFilesStreamPost,
        BodyUpsertAgentAgentsPost,
        CancelResponse,
        CardDisplayField,
        Channel,
        CheckBoxColumn,
        Collection,
        CollectionConfig,
        CollectionDestination,
        CollectionViewStateInput,
        CollectionViewStateInputViewsValue,
        CollectionViewStateOutput,
        CollectionViewStateOutputViewsValue,
        ColumnType,
        ColumnTypeBase,
        Condition,
        ConditionField,
        ConditionOperator,
        ConnectIntegrationRequest,
        ConnectIntegrationRequestAuthType,
        Copilot,
        CopilotConfig,
        CopilotConfigCodeTheme,
        CopilotConfigFabValue,
        CopilotConfigMode,
        CreateEntityRequest,
        CreateIntegrationsResponse,
        CreatePulseRequest,
        CreatePulseResponse,
        CreateTagResponse,
        CronTriggerConfig,
        CronTriggerConfigAction,
        Custom,
        DailyUsage,
        DataType,
        DateTimeColumn,
        DefaultInput,
        DefaultOutput,
        DeleteHookResponse,
        DeleteResponse,
        DeleteTriggerResponse,
        DeleteViewResponse,
        Dependency,
        DeterminedBillingLimits,
        Dimensions,
        Document,
        DocumentCreatedBy,
        DocumentDataValue,
        DocumentLastUpdatedBy,
        DocumentResponse,
        EdgeUi,
        EntityQueryRequest,
        EntityResponse,
        EntitySearchRequest,
        EntitySearchRequestMode,
        EntitySearchRequestReturnFormat,
        Environment,
        EnvironmentConfig,
        EnvironmentDeploymentConfig,
        EnvironmentDeploymentConfigRevisionLookup,
        EnvironmentDeploymentDocument,
        EventVersion,
        ExecuteToolRequest,
        ExecuteToolResponse,
        ExecuteTriggerResponse,
        Favor,
        FavoriteItem,
        FavoriteRef,
        FieldMapping,
        File,
        FilesAttribute,
        FilesResponse,
        FilterOperator,
        FilterType,
        Flags,
        FluentQueryRequest,
        FluentQueryRequestWithItem,
        FriendlyInvoice,
        FriendlyPaymentMethods,
        GenerateAiSuggestionRequest,
        HookUpdate,
        HooksListResponse,
        Html2Text,
        Http,
        HttpValidationError,
        Identity,
        IdentityDetails,
        IdentityTypes,
        Integration,
        IntegrationAuthType,
        IntegrationConnection,
        IntegrationConnectionAuthType,
        IntegrationConnectionIntegrationType,
        IntegrationWithConnections,
        IntegrationWithConnectionsId,
        Interval,
        IntervalTypes,
        Invoice,
        InvoiceMeta,
        InvoiceStatus,
        JsonColumn,
        KanbanViewInput,
        KanbanViewOutput,
        KanbanViewSettingsInput,
        KanbanViewSettingsOutput,
        LegacyIdentity,
        LegacyIdentityDetails,
        LineItem,
        ListTagsResponse,
        ListToolsResponse,
        ListTriggersResponse,
        Mapping,
        MarkDownWithContext,
        MarkdownColumn,
        MarkdownSplitterConfig,
        McpAuthType,
        Me,
        MeUpdate,
        Mention,
        MentionParticipant,
        Message,
        MessageChunk,
        ModelProvider,
        MultiPageCrawlerSettingsInput,
        MultiPageCrawlerSettingsInputScraper,
        MultiPageCrawlerSettingsInputTextExtractor,
        MultiPageCrawlerSettingsOutput,
        MultiPageCrawlerSettingsOutputScraper,
        MultiPageCrawlerSettingsOutputTextExtractor,
        MultiSelectColumn,
        NodeUi,
        Notification,
        NotificationAction,
        NotificationActionType,
        NotificationSeverity,
        NotificationType,
        NotionFilterBy,
        NotionFilterOptions,
        NotionOAuthRequest,
        NumberColumn,
        NumberColumnDefault,
        NumberColumnMaxValue,
        NumberColumnMinValue,
        OAuthAuthType,
        Organization,
        ParagraphSplitterConfig,
        Participant,
        ParticipantType,
        PeopleColumn,
        PlaceholderInput,
        PlaceholderInputType,
        PlaceholderOutput,
        PlaceholderOutputType,
        Plan,
        PlanTypes,
        Playwright,
        PlaywrightWaitForLoadState,
        Position,
        Prompt,
        PromptRole,
        PublicCopilotConfig,
        PublicCopilotConfigCodeTheme,
        PublicCopilotConfigFabValue,
        PublicCopilotConfigMode,
        PublicCopilotResponse,
        PulseFeedResponse,
        PulseHook,
        PulseHookInput,
        PulseTargetConfig,
        QueryBuilderRequest,
        QueryBuilderRequestGroupByItem,
        QueryBuilderRequestSortBy,
        QueryBuilderRequestSortDirection,
        QueryBuilderRequestTagMode,
        QueryRequest,
        QuerySort,
        Readability,
        RecursiveSplitterConfig,
        RelationColumn,
        RenameRequest,
        RenameResponse,
        ReqBody,
        RequestBody,
        Resource,
        ResourceResourceType,
        ResponseModelUsage,
        Result,
        RotateApiKeysRequest,
        Rule,
        RulesInput,
        RulesOutput,
        RunLog,
        RunLogPagination,
        Schedule,
        SchemaResponse,
        SchemasResponse,
        ScoutHook,
        ScoutHookConfigHttp,
        ScoutHookEventDiscriminator,
        ScoutHookEventDiscriminatorType,
        ScoutHookEventTrigger,
        ScoutHookResponse,
        ScoutHookUpdate,
        ScoutHookUpdateTriggeringEventsItem,
        ScoutHooksResponse,
        ScoutUser,
        SearchRequest,
        SearchRequestSearchType,
        SelectColumn,
        SelectOptionItem,
        SentenceSplitterConfig,
        ServiceInfo,
        SinglePageCrawlerSettingsInput,
        SinglePageCrawlerSettingsInputScraper,
        SinglePageCrawlerSettingsInputTextExtractor,
        SinglePageCrawlerSettingsOutput,
        SinglePageCrawlerSettingsOutputScraper,
        SinglePageCrawlerSettingsOutputTextExtractor,
        SitemapCrawlerSettingsInput,
        SitemapCrawlerSettingsInputScraper,
        SitemapCrawlerSettingsInputTextExtractor,
        SitemapCrawlerSettingsOutput,
        SitemapCrawlerSettingsOutputScraper,
        SitemapCrawlerSettingsOutputTextExtractor,
        SlackEventResponse,
        SlackMessageRequest,
        SlackReactionRequest,
        SlackTriggerConfigInput,
        SlackTriggerConfigInputAction,
        SlackTriggerConfigOutput,
        SlackTriggerConfigOutputAction,
        SlackUrlVerification,
        SortDirection,
        SourceArchetype,
        SourceArchetypeIntegrationVersion,
        SourceSync,
        SourceSyncCrawlSettingsInput,
        SourceSyncCrawlSettingsInputMode,
        SourceSyncCrawlSettingsOutput,
        SourceSyncCrawlSettingsOutputMode,
        SourceSyncGoogleDriveSettings,
        SourceSyncNotionSettingsInput,
        SourceSyncNotionSettingsOutput,
        SourceSyncPageCrawlSettingsInput,
        SourceSyncPageCrawlSettingsInputMode,
        SourceSyncPageCrawlSettingsOutput,
        SourceSyncPageCrawlSettingsOutputMode,
        SourceSyncSitemapSettingsInput,
        SourceSyncSitemapSettingsInputMode,
        SourceSyncSitemapSettingsOutput,
        SourceSyncSitemapSettingsOutputMode,
        SourceSyncWebsiteSettings,
        SourceSyncWebsiteSettingsSplitter,
        SrcAppHttpRoutesBillingBillingHourlyData,
        SrcAppHttpRoutesBillingBillingHourlyResponse,
        SrcAppHttpRoutesBillingChangeBillingPlanResponse,
        SrcAppHttpRoutesBillingCreatePortalSessionData,
        SrcAppHttpRoutesBillingCreatePortalSessionResponse,
        SrcAppHttpRoutesBillingFreePlanUsageData,
        SrcAppHttpRoutesBillingFreePlanUsageResponse,
        SrcAppHttpRoutesBillingGetBillingData,
        SrcAppHttpRoutesBillingGetBillingResponse,
        SrcAppHttpRoutesBillingGetInfoGetInfoResponse,
        SrcAppHttpRoutesBillingGetInvoicesData,
        SrcAppHttpRoutesBillingGetInvoicesResponse,
        SrcAppHttpRoutesBillingGetNotificationsResponse,
        SrcAppHttpRoutesBillingRenewPlansData,
        SrcAppHttpRoutesBillingRenewPlansResponse,
        SrcAppHttpRoutesCollectionCreateCollectionResponse,
        SrcAppHttpRoutesCollectionCreateSyncResponse,
        SrcAppHttpRoutesCollectionCreateTableResponse,
        SrcAppHttpRoutesCollectionDeleteCollectionResponse,
        SrcAppHttpRoutesCollectionDeleteDocumentsResponse,
        SrcAppHttpRoutesCollectionDeleteSyncResponse,
        SrcAppHttpRoutesCollectionDeleteTableResponse,
        SrcAppHttpRoutesCollectionGetCollectionResponse,
        SrcAppHttpRoutesCollectionGetCollectionsResponse,
        SrcAppHttpRoutesCollectionGetDocumentResponse,
        SrcAppHttpRoutesCollectionGetDocumentsResponse,
        SrcAppHttpRoutesCollectionGetSyncResponse,
        SrcAppHttpRoutesCollectionGetSyncsResponse,
        SrcAppHttpRoutesCollectionGetTableResponse,
        SrcAppHttpRoutesCollectionGetTablesResponse,
        SrcAppHttpRoutesCollectionListCollectionSyncsResponseModel,
        SrcAppHttpRoutesCollectionListSourceArchetypesResponseModel,
        SrcAppHttpRoutesCollectionParseFileResponse,
        SrcAppHttpRoutesCollectionSyncTableResponse,
        SrcAppHttpRoutesCollectionUpdateCollectionResponse,
        SrcAppHttpRoutesCollectionUpdateDocumentResponse,
        SrcAppHttpRoutesCollectionUpdateSyncResponse,
        SrcAppHttpRoutesCollectionUpdateTableResponse,
        SrcAppHttpRoutesDriveCreateDriveCrawlPayload,
        SrcAppHttpRoutesDriveCreateDriveCrawlPayloadSourceSyncSettings,
        SrcAppHttpRoutesDriveGrantAccessPayload,
        SrcAppHttpRoutesDriveRevokeAccessPayload,
        SrcAppHttpRoutesInboxHandleMessageIncomingMessage,
        SrcAppHttpRoutesInboxHandleMessageIncomingMessageContent,
        SrcAppHttpRoutesInboxHandleMessageIncomingMessageContentType,
        SrcAppHttpRoutesInboxHandleMessageInteractionRequest,
        SrcAppHttpRoutesInboxHandleMessageInteractionRequestParticipantsItem,
        SrcAppHttpRoutesIntegrationMcpConnectMcpPayload,
        SrcAppHttpRoutesIntegrationMcpExchangeMcpAuthPayload,
        SrcAppHttpRoutesOnboardingHandleGetMeResponse,
        SrcAppHttpRoutesOnboardingHandleUpdateMeResponse,
        SrcAppHttpRoutesRootGetInfoResponse,
        SrcAppHttpRoutesTagsCreateTagPayload,
        SrcAppHttpRoutesTagsUpdateTagPayload,
        SrcAppHttpRoutesTriggerCreateTriggerResponse,
        SrcAppHttpRoutesWorldInteractIncomingMessage,
        SrcAppHttpRoutesWorldInteractIncomingMessageContent,
        SrcAppHttpRoutesWorldInteractIncomingMessageContentItem,
        SrcAppHttpRoutesWorldInteractInteractionRequest,
        SrcHandlersCreateCopilotResponse,
        SrcHandlersCreateWorkflowResponse,
        SrcHandlersCreateWorkflowRevisionResponse,
        SrcHandlersDeleteCopilotResponse,
        SrcHandlersDeleteWorkflowResponse,
        SrcHandlersDeleteWorkflowRevisionResponse,
        SrcHandlersGetCopilotResponse,
        SrcHandlersGetWorkflowEnvironmentsResponse,
        SrcHandlersGetWorkflowResponse,
        SrcHandlersListCopilotsResponse,
        SrcHandlersListWorkflowRevisionsResponse,
        SrcHandlersListWorkflowsResponse,
        SrcHandlersPromoteWorkflowRevisionResponse,
        SrcHandlersUpdateCopilotResponse,
        SrcHandlersUpdateWorkflowEnvironmentResponse,
        SrcHandlersUpdateWorkflowResponse,
        SrcHandlersUpdateWorkflowRevisionResponse,
        StoreResponse,
        StripeProvider,
        StripeProviderMeta,
        Subscription,
        Sync,
        SyncConfigInput,
        SyncConfigInputSourceSettings,
        SyncConfigOutput,
        SyncConfigOutputSourceSettings,
        Table,
        TableConfigOutput,
        TableConfigOutputSchemaItem,
        TableViewInput,
        TableViewOutput,
        TableViewSettingsInput,
        TableViewSettingsInputRowHeight,
        TableViewSettingsOutput,
        TableViewSettingsOutputRowHeight,
        Tag,
        TagsResponse,
        TextExtractor,
        TextExtractorConfig,
        TextLongColumn,
        TextShortColumn,
        Tool,
        ToolConfigResource,
        ToolConfigResourceType,
        ToolDetails,
        ToolsData,
        ToolsResponse,
        TrafilaturaInput,
        TrafilaturaInputTrafilaturaType,
        TrafilaturaOutput,
        TrafilaturaOutputTrafilaturaType,
        Trigger,
        TriggerStatus,
        TriggerTriggerConfig,
        TypescriptAutomationConfig,
        Units,
        UpdateCronAuthResponse,
        UpdateEntityRequest,
        UpdateQuestionnaireFilesRequest,
        UpdateTagResponse,
        UpdateTagsRequest,
        UpdateTriggerResponse,
        UrlColumn,
        Usage,
        UsageTypes,
        UserIdentity,
        UserIdentityDetails,
        UserOrganizationConfig,
        ValidationError,
        ValidationErrorLocItem,
        ViewFilter,
        ViewListResponse,
        ViewListResponseDataItem,
        ViewQueryInput,
        ViewQueryOutput,
        ViewResponse,
        ViewResponseData,
        ViewStateResponse,
        ViewVisibility,
        Workflow,
        WorkflowActor,
        WorkflowActorType,
        WorkflowConfigInput,
        WorkflowConfigOutput,
        WorkflowExecute,
        WorkflowHook,
        WorkflowHookInput,
        WorkflowNoteInput,
        WorkflowNoteOutput,
        WorkflowRun,
        WorkflowRunCompleted,
        WorkflowRunCompletedData,
        WorkflowRunCompletedEnvironment,
        WorkflowRunFailed,
        WorkflowRunFailedData,
        WorkflowRunFailedEnvironment,
        WorkflowRunResponse,
        WorkflowRunStarted,
        WorkflowRunStartedData,
        WorkflowRunStartedEnvironment,
        WorkflowRunStateValue,
        WorkflowRunStopReason,
        WorkflowRunStreamResponse,
        WorkflowTargetConfig,
    )
    from .errors import UnprocessableEntityError
    from . import (
        collections,
        copilots,
        documents,
        environments,
        integrations,
        organizations,
        revisions,
        sources,
        syncs,
        tables,
        triggers,
        usage,
        workflow_logs,
        workflow_revisions,
        workflows,
    )
    from .client import AsyncScout, Scout
    from .collections import (
        CreateViewRequestSettings,
        CreateViewRequestType,
        UpdateViewRequestSettings,
        UpdateViewRequestType,
    )
    from .documents import (
        DocumentsCreateRequestBody,
        DocumentsCreateRequestBodyItemValue,
        DocumentsCreateRequestBodyOneValue,
        DocumentsCreateRequestBodyZeroValue,
        DocumentsUpdateBatchRequestBody,
        DocumentsUpdateBatchRequestBodyItemValue,
        DocumentsUpdateBatchRequestBodyOneValue,
        DocumentsUpdateBatchRequestBodyZeroValue,
        DocumentsUpdateRequestValue,
    )
    from .environment import ScoutEnvironment
    from .tables import TableConfigInputSchemaItem, TableDataSchemaItem
    from .triggers import TriggersCreateRequest, TriggersExecuteSlackResponse, TriggersUpdateRequest
    from .version import __version__
    from .workflow_logs import WorkflowLogsListLogsResponse
    from .workflows import (
        SrcHandlersWorkflowsExecuteWithConfigReqBodyInputsValue,
        WorkflowsRunRequestInputsValue,
        WorkflowsRunStreamRequestInputsValue,
        WorkflowsRunWithConfigResponse,
        WorkflowsRunWithConfigResponseZero,
    )
_dynamic_imports: typing.Dict[str, str] = {
    "ActionType": ".types",
    "ActivitySchema": ".types",
    "Actor": ".types",
    "ActorIdentity": ".types",
    "ActorIdentityId": ".types",
    "ActorIdentityType": ".types",
    "AgentHook": ".types",
    "AgentHookInput": ".types",
    "AgentRevision": ".types",
    "AgentRevisionModel": ".types",
    "AgentRevisionResponseStyle": ".types",
    "AgentRevisionToolConfigValue": ".types",
    "AgentTargetConfig": ".types",
    "AiAgent": ".types",
    "ApiKeyAuthType": ".types",
    "ApiKeyIdentity": ".types",
    "ApiKeyIdentityDetails": ".types",
    "AsyncScout": ".client",
    "AutomationHook": ".types",
    "AutomationHookInput": ".types",
    "AutomationTargetConfig": ".types",
    "BareInput": ".types",
    "BareOutput": ".types",
    "Baseline": ".types",
    "BatchCreateRequest": ".types",
    "BatchGenerateRequest": ".types",
    "Billing": ".types",
    "BillingCycle": ".types",
    "BillingCycles": ".types",
    "BillingLimits": ".types",
    "BillingUsage": ".types",
    "BlockConfigItemBoolean": ".types",
    "BlockConfigItemJson": ".types",
    "BlockConfigItemLlm": ".types",
    "BlockConfigItemNumber": ".types",
    "BlockConfigItemNumberDefaultValue": ".types",
    "BlockConfigItemNumberMaximumValue": ".types",
    "BlockConfigItemNumberMinimumValue": ".types",
    "BlockConfigItemNumberValue": ".types",
    "BlockConfigItemSelect": ".types",
    "BlockConfigItemTextLong": ".types",
    "BlockConfigItemTextLongValue": ".types",
    "BlockConfigItemTextShort": ".types",
    "BlockInput": ".types",
    "BlockInputBlockConfigItem": ".types",
    "BlockOutput": ".types",
    "BlockOutputBlockConfigItem": ".types",
    "BlockRun": ".types",
    "BlockRunCompleted": ".types",
    "BlockRunCompletedData": ".types",
    "BlockRunCompletedEnvironment": ".types",
    "BlockRunFailed": ".types",
    "BlockRunFailedData": ".types",
    "BlockRunFailedEnvironment": ".types",
    "BlockRunStarted": ".types",
    "BlockRunStartedData": ".types",
    "BlockRunStartedEnvironment": ".types",
    "BlockRunUsage": ".types",
    "BlockStateUpdated": ".types",
    "BlockStateUpdatedData": ".types",
    "BlockStateUpdatedDataUpdateType": ".types",
    "BlockStateUpdatedEnvironment": ".types",
    "BodyParseFileV2FilesParsePost": ".types",
    "BodyUploadFilesToDriveDriveFilesPost": ".types",
    "BodyUploadPrivateFilesInboxSessionIdFilesPost": ".types",
    "BodyUploadPulseFilesStreamPulseFilesStreamPost": ".types",
    "BodyUpsertAgentAgentsPost": ".types",
    "CancelResponse": ".types",
    "CardDisplayField": ".types",
    "Channel": ".types",
    "CheckBoxColumn": ".types",
    "Collection": ".types",
    "CollectionConfig": ".types",
    "CollectionDestination": ".types",
    "CollectionViewStateInput": ".types",
    "CollectionViewStateInputViewsValue": ".types",
    "CollectionViewStateOutput": ".types",
    "CollectionViewStateOutputViewsValue": ".types",
    "ColumnType": ".types",
    "ColumnTypeBase": ".types",
    "Condition": ".types",
    "ConditionField": ".types",
    "ConditionOperator": ".types",
    "ConnectIntegrationRequest": ".types",
    "ConnectIntegrationRequestAuthType": ".types",
    "Copilot": ".types",
    "CopilotConfig": ".types",
    "CopilotConfigCodeTheme": ".types",
    "CopilotConfigFabValue": ".types",
    "CopilotConfigMode": ".types",
    "CreateEntityRequest": ".types",
    "CreateIntegrationsResponse": ".types",
    "CreatePulseRequest": ".types",
    "CreatePulseResponse": ".types",
    "CreateTagResponse": ".types",
    "CreateViewRequestSettings": ".collections",
    "CreateViewRequestType": ".collections",
    "CronTriggerConfig": ".types",
    "CronTriggerConfigAction": ".types",
    "Custom": ".types",
    "DailyUsage": ".types",
    "DataType": ".types",
    "DateTimeColumn": ".types",
    "DefaultInput": ".types",
    "DefaultOutput": ".types",
    "DeleteHookResponse": ".types",
    "DeleteResponse": ".types",
    "DeleteTriggerResponse": ".types",
    "DeleteViewResponse": ".types",
    "Dependency": ".types",
    "DeterminedBillingLimits": ".types",
    "Dimensions": ".types",
    "Document": ".types",
    "DocumentCreatedBy": ".types",
    "DocumentDataValue": ".types",
    "DocumentLastUpdatedBy": ".types",
    "DocumentResponse": ".types",
    "DocumentsCreateRequestBody": ".documents",
    "DocumentsCreateRequestBodyItemValue": ".documents",
    "DocumentsCreateRequestBodyOneValue": ".documents",
    "DocumentsCreateRequestBodyZeroValue": ".documents",
    "DocumentsUpdateBatchRequestBody": ".documents",
    "DocumentsUpdateBatchRequestBodyItemValue": ".documents",
    "DocumentsUpdateBatchRequestBodyOneValue": ".documents",
    "DocumentsUpdateBatchRequestBodyZeroValue": ".documents",
    "DocumentsUpdateRequestValue": ".documents",
    "EdgeUi": ".types",
    "EntityQueryRequest": ".types",
    "EntityResponse": ".types",
    "EntitySearchRequest": ".types",
    "EntitySearchRequestMode": ".types",
    "EntitySearchRequestReturnFormat": ".types",
    "Environment": ".types",
    "EnvironmentConfig": ".types",
    "EnvironmentDeploymentConfig": ".types",
    "EnvironmentDeploymentConfigRevisionLookup": ".types",
    "EnvironmentDeploymentDocument": ".types",
    "EventVersion": ".types",
    "ExecuteToolRequest": ".types",
    "ExecuteToolResponse": ".types",
    "ExecuteTriggerResponse": ".types",
    "Favor": ".types",
    "FavoriteItem": ".types",
    "FavoriteRef": ".types",
    "FieldMapping": ".types",
    "File": ".types",
    "FilesAttribute": ".types",
    "FilesResponse": ".types",
    "FilterOperator": ".types",
    "FilterType": ".types",
    "Flags": ".types",
    "FluentQueryRequest": ".types",
    "FluentQueryRequestWithItem": ".types",
    "FriendlyInvoice": ".types",
    "FriendlyPaymentMethods": ".types",
    "GenerateAiSuggestionRequest": ".types",
    "HookUpdate": ".types",
    "HooksListResponse": ".types",
    "Html2Text": ".types",
    "Http": ".types",
    "HttpValidationError": ".types",
    "Identity": ".types",
    "IdentityDetails": ".types",
    "IdentityTypes": ".types",
    "Integration": ".types",
    "IntegrationAuthType": ".types",
    "IntegrationConnection": ".types",
    "IntegrationConnectionAuthType": ".types",
    "IntegrationConnectionIntegrationType": ".types",
    "IntegrationWithConnections": ".types",
    "IntegrationWithConnectionsId": ".types",
    "Interval": ".types",
    "IntervalTypes": ".types",
    "Invoice": ".types",
    "InvoiceMeta": ".types",
    "InvoiceStatus": ".types",
    "JsonColumn": ".types",
    "KanbanViewInput": ".types",
    "KanbanViewOutput": ".types",
    "KanbanViewSettingsInput": ".types",
    "KanbanViewSettingsOutput": ".types",
    "LegacyIdentity": ".types",
    "LegacyIdentityDetails": ".types",
    "LineItem": ".types",
    "ListTagsResponse": ".types",
    "ListToolsResponse": ".types",
    "ListTriggersResponse": ".types",
    "Mapping": ".types",
    "MarkDownWithContext": ".types",
    "MarkdownColumn": ".types",
    "MarkdownSplitterConfig": ".types",
    "McpAuthType": ".types",
    "Me": ".types",
    "MeUpdate": ".types",
    "Mention": ".types",
    "MentionParticipant": ".types",
    "Message": ".types",
    "MessageChunk": ".types",
    "ModelProvider": ".types",
    "MultiPageCrawlerSettingsInput": ".types",
    "MultiPageCrawlerSettingsInputScraper": ".types",
    "MultiPageCrawlerSettingsInputTextExtractor": ".types",
    "MultiPageCrawlerSettingsOutput": ".types",
    "MultiPageCrawlerSettingsOutputScraper": ".types",
    "MultiPageCrawlerSettingsOutputTextExtractor": ".types",
    "MultiSelectColumn": ".types",
    "NodeUi": ".types",
    "Notification": ".types",
    "NotificationAction": ".types",
    "NotificationActionType": ".types",
    "NotificationSeverity": ".types",
    "NotificationType": ".types",
    "NotionFilterBy": ".types",
    "NotionFilterOptions": ".types",
    "NotionOAuthRequest": ".types",
    "NumberColumn": ".types",
    "NumberColumnDefault": ".types",
    "NumberColumnMaxValue": ".types",
    "NumberColumnMinValue": ".types",
    "OAuthAuthType": ".types",
    "Organization": ".types",
    "ParagraphSplitterConfig": ".types",
    "Participant": ".types",
    "ParticipantType": ".types",
    "PeopleColumn": ".types",
    "PlaceholderInput": ".types",
    "PlaceholderInputType": ".types",
    "PlaceholderOutput": ".types",
    "PlaceholderOutputType": ".types",
    "Plan": ".types",
    "PlanTypes": ".types",
    "Playwright": ".types",
    "PlaywrightWaitForLoadState": ".types",
    "Position": ".types",
    "Prompt": ".types",
    "PromptRole": ".types",
    "PublicCopilotConfig": ".types",
    "PublicCopilotConfigCodeTheme": ".types",
    "PublicCopilotConfigFabValue": ".types",
    "PublicCopilotConfigMode": ".types",
    "PublicCopilotResponse": ".types",
    "PulseFeedResponse": ".types",
    "PulseHook": ".types",
    "PulseHookInput": ".types",
    "PulseTargetConfig": ".types",
    "QueryBuilderRequest": ".types",
    "QueryBuilderRequestGroupByItem": ".types",
    "QueryBuilderRequestSortBy": ".types",
    "QueryBuilderRequestSortDirection": ".types",
    "QueryBuilderRequestTagMode": ".types",
    "QueryRequest": ".types",
    "QuerySort": ".types",
    "Readability": ".types",
    "RecursiveSplitterConfig": ".types",
    "RelationColumn": ".types",
    "RenameRequest": ".types",
    "RenameResponse": ".types",
    "ReqBody": ".types",
    "RequestBody": ".types",
    "Resource": ".types",
    "ResourceResourceType": ".types",
    "ResponseModelUsage": ".types",
    "Result": ".types",
    "RotateApiKeysRequest": ".types",
    "Rule": ".types",
    "RulesInput": ".types",
    "RulesOutput": ".types",
    "RunLog": ".types",
    "RunLogPagination": ".types",
    "Schedule": ".types",
    "SchemaResponse": ".types",
    "SchemasResponse": ".types",
    "Scout": ".client",
    "ScoutEnvironment": ".environment",
    "ScoutHook": ".types",
    "ScoutHookConfigHttp": ".types",
    "ScoutHookEventDiscriminator": ".types",
    "ScoutHookEventDiscriminatorType": ".types",
    "ScoutHookEventTrigger": ".types",
    "ScoutHookResponse": ".types",
    "ScoutHookUpdate": ".types",
    "ScoutHookUpdateTriggeringEventsItem": ".types",
    "ScoutHooksResponse": ".types",
    "ScoutUser": ".types",
    "SearchRequest": ".types",
    "SearchRequestSearchType": ".types",
    "SelectColumn": ".types",
    "SelectOptionItem": ".types",
    "SentenceSplitterConfig": ".types",
    "ServiceInfo": ".types",
    "SinglePageCrawlerSettingsInput": ".types",
    "SinglePageCrawlerSettingsInputScraper": ".types",
    "SinglePageCrawlerSettingsInputTextExtractor": ".types",
    "SinglePageCrawlerSettingsOutput": ".types",
    "SinglePageCrawlerSettingsOutputScraper": ".types",
    "SinglePageCrawlerSettingsOutputTextExtractor": ".types",
    "SitemapCrawlerSettingsInput": ".types",
    "SitemapCrawlerSettingsInputScraper": ".types",
    "SitemapCrawlerSettingsInputTextExtractor": ".types",
    "SitemapCrawlerSettingsOutput": ".types",
    "SitemapCrawlerSettingsOutputScraper": ".types",
    "SitemapCrawlerSettingsOutputTextExtractor": ".types",
    "SlackEventResponse": ".types",
    "SlackMessageRequest": ".types",
    "SlackReactionRequest": ".types",
    "SlackTriggerConfigInput": ".types",
    "SlackTriggerConfigInputAction": ".types",
    "SlackTriggerConfigOutput": ".types",
    "SlackTriggerConfigOutputAction": ".types",
    "SlackUrlVerification": ".types",
    "SortDirection": ".types",
    "SourceArchetype": ".types",
    "SourceArchetypeIntegrationVersion": ".types",
    "SourceSync": ".types",
    "SourceSyncCrawlSettingsInput": ".types",
    "SourceSyncCrawlSettingsInputMode": ".types",
    "SourceSyncCrawlSettingsOutput": ".types",
    "SourceSyncCrawlSettingsOutputMode": ".types",
    "SourceSyncGoogleDriveSettings": ".types",
    "SourceSyncNotionSettingsInput": ".types",
    "SourceSyncNotionSettingsOutput": ".types",
    "SourceSyncPageCrawlSettingsInput": ".types",
    "SourceSyncPageCrawlSettingsInputMode": ".types",
    "SourceSyncPageCrawlSettingsOutput": ".types",
    "SourceSyncPageCrawlSettingsOutputMode": ".types",
    "SourceSyncSitemapSettingsInput": ".types",
    "SourceSyncSitemapSettingsInputMode": ".types",
    "SourceSyncSitemapSettingsOutput": ".types",
    "SourceSyncSitemapSettingsOutputMode": ".types",
    "SourceSyncWebsiteSettings": ".types",
    "SourceSyncWebsiteSettingsSplitter": ".types",
    "SrcAppHttpRoutesBillingBillingHourlyData": ".types",
    "SrcAppHttpRoutesBillingBillingHourlyResponse": ".types",
    "SrcAppHttpRoutesBillingChangeBillingPlanResponse": ".types",
    "SrcAppHttpRoutesBillingCreatePortalSessionData": ".types",
    "SrcAppHttpRoutesBillingCreatePortalSessionResponse": ".types",
    "SrcAppHttpRoutesBillingFreePlanUsageData": ".types",
    "SrcAppHttpRoutesBillingFreePlanUsageResponse": ".types",
    "SrcAppHttpRoutesBillingGetBillingData": ".types",
    "SrcAppHttpRoutesBillingGetBillingResponse": ".types",
    "SrcAppHttpRoutesBillingGetInfoGetInfoResponse": ".types",
    "SrcAppHttpRoutesBillingGetInvoicesData": ".types",
    "SrcAppHttpRoutesBillingGetInvoicesResponse": ".types",
    "SrcAppHttpRoutesBillingGetNotificationsResponse": ".types",
    "SrcAppHttpRoutesBillingRenewPlansData": ".types",
    "SrcAppHttpRoutesBillingRenewPlansResponse": ".types",
    "SrcAppHttpRoutesCollectionCreateCollectionResponse": ".types",
    "SrcAppHttpRoutesCollectionCreateSyncResponse": ".types",
    "SrcAppHttpRoutesCollectionCreateTableResponse": ".types",
    "SrcAppHttpRoutesCollectionDeleteCollectionResponse": ".types",
    "SrcAppHttpRoutesCollectionDeleteDocumentsResponse": ".types",
    "SrcAppHttpRoutesCollectionDeleteSyncResponse": ".types",
    "SrcAppHttpRoutesCollectionDeleteTableResponse": ".types",
    "SrcAppHttpRoutesCollectionGetCollectionResponse": ".types",
    "SrcAppHttpRoutesCollectionGetCollectionsResponse": ".types",
    "SrcAppHttpRoutesCollectionGetDocumentResponse": ".types",
    "SrcAppHttpRoutesCollectionGetDocumentsResponse": ".types",
    "SrcAppHttpRoutesCollectionGetSyncResponse": ".types",
    "SrcAppHttpRoutesCollectionGetSyncsResponse": ".types",
    "SrcAppHttpRoutesCollectionGetTableResponse": ".types",
    "SrcAppHttpRoutesCollectionGetTablesResponse": ".types",
    "SrcAppHttpRoutesCollectionListCollectionSyncsResponseModel": ".types",
    "SrcAppHttpRoutesCollectionListSourceArchetypesResponseModel": ".types",
    "SrcAppHttpRoutesCollectionParseFileResponse": ".types",
    "SrcAppHttpRoutesCollectionSyncTableResponse": ".types",
    "SrcAppHttpRoutesCollectionUpdateCollectionResponse": ".types",
    "SrcAppHttpRoutesCollectionUpdateDocumentResponse": ".types",
    "SrcAppHttpRoutesCollectionUpdateSyncResponse": ".types",
    "SrcAppHttpRoutesCollectionUpdateTableResponse": ".types",
    "SrcAppHttpRoutesDriveCreateDriveCrawlPayload": ".types",
    "SrcAppHttpRoutesDriveCreateDriveCrawlPayloadSourceSyncSettings": ".types",
    "SrcAppHttpRoutesDriveGrantAccessPayload": ".types",
    "SrcAppHttpRoutesDriveRevokeAccessPayload": ".types",
    "SrcAppHttpRoutesInboxHandleMessageIncomingMessage": ".types",
    "SrcAppHttpRoutesInboxHandleMessageIncomingMessageContent": ".types",
    "SrcAppHttpRoutesInboxHandleMessageIncomingMessageContentType": ".types",
    "SrcAppHttpRoutesInboxHandleMessageInteractionRequest": ".types",
    "SrcAppHttpRoutesInboxHandleMessageInteractionRequestParticipantsItem": ".types",
    "SrcAppHttpRoutesIntegrationMcpConnectMcpPayload": ".types",
    "SrcAppHttpRoutesIntegrationMcpExchangeMcpAuthPayload": ".types",
    "SrcAppHttpRoutesOnboardingHandleGetMeResponse": ".types",
    "SrcAppHttpRoutesOnboardingHandleUpdateMeResponse": ".types",
    "SrcAppHttpRoutesRootGetInfoResponse": ".types",
    "SrcAppHttpRoutesTagsCreateTagPayload": ".types",
    "SrcAppHttpRoutesTagsUpdateTagPayload": ".types",
    "SrcAppHttpRoutesTriggerCreateTriggerResponse": ".types",
    "SrcAppHttpRoutesWorldInteractIncomingMessage": ".types",
    "SrcAppHttpRoutesWorldInteractIncomingMessageContent": ".types",
    "SrcAppHttpRoutesWorldInteractIncomingMessageContentItem": ".types",
    "SrcAppHttpRoutesWorldInteractInteractionRequest": ".types",
    "SrcHandlersCreateCopilotResponse": ".types",
    "SrcHandlersCreateWorkflowResponse": ".types",
    "SrcHandlersCreateWorkflowRevisionResponse": ".types",
    "SrcHandlersDeleteCopilotResponse": ".types",
    "SrcHandlersDeleteWorkflowResponse": ".types",
    "SrcHandlersDeleteWorkflowRevisionResponse": ".types",
    "SrcHandlersGetCopilotResponse": ".types",
    "SrcHandlersGetWorkflowEnvironmentsResponse": ".types",
    "SrcHandlersGetWorkflowResponse": ".types",
    "SrcHandlersListCopilotsResponse": ".types",
    "SrcHandlersListWorkflowRevisionsResponse": ".types",
    "SrcHandlersListWorkflowsResponse": ".types",
    "SrcHandlersPromoteWorkflowRevisionResponse": ".types",
    "SrcHandlersUpdateCopilotResponse": ".types",
    "SrcHandlersUpdateWorkflowEnvironmentResponse": ".types",
    "SrcHandlersUpdateWorkflowResponse": ".types",
    "SrcHandlersUpdateWorkflowRevisionResponse": ".types",
    "SrcHandlersWorkflowsExecuteWithConfigReqBodyInputsValue": ".workflows",
    "StoreResponse": ".types",
    "StripeProvider": ".types",
    "StripeProviderMeta": ".types",
    "Subscription": ".types",
    "Sync": ".types",
    "SyncConfigInput": ".types",
    "SyncConfigInputSourceSettings": ".types",
    "SyncConfigOutput": ".types",
    "SyncConfigOutputSourceSettings": ".types",
    "Table": ".types",
    "TableConfigInputSchemaItem": ".tables",
    "TableConfigOutput": ".types",
    "TableConfigOutputSchemaItem": ".types",
    "TableDataSchemaItem": ".tables",
    "TableViewInput": ".types",
    "TableViewOutput": ".types",
    "TableViewSettingsInput": ".types",
    "TableViewSettingsInputRowHeight": ".types",
    "TableViewSettingsOutput": ".types",
    "TableViewSettingsOutputRowHeight": ".types",
    "Tag": ".types",
    "TagsResponse": ".types",
    "TextExtractor": ".types",
    "TextExtractorConfig": ".types",
    "TextLongColumn": ".types",
    "TextShortColumn": ".types",
    "Tool": ".types",
    "ToolConfigResource": ".types",
    "ToolConfigResourceType": ".types",
    "ToolDetails": ".types",
    "ToolsData": ".types",
    "ToolsResponse": ".types",
    "TrafilaturaInput": ".types",
    "TrafilaturaInputTrafilaturaType": ".types",
    "TrafilaturaOutput": ".types",
    "TrafilaturaOutputTrafilaturaType": ".types",
    "Trigger": ".types",
    "TriggerStatus": ".types",
    "TriggerTriggerConfig": ".types",
    "TriggersCreateRequest": ".triggers",
    "TriggersExecuteSlackResponse": ".triggers",
    "TriggersUpdateRequest": ".triggers",
    "TypescriptAutomationConfig": ".types",
    "Units": ".types",
    "UnprocessableEntityError": ".errors",
    "UpdateCronAuthResponse": ".types",
    "UpdateEntityRequest": ".types",
    "UpdateQuestionnaireFilesRequest": ".types",
    "UpdateTagResponse": ".types",
    "UpdateTagsRequest": ".types",
    "UpdateTriggerResponse": ".types",
    "UpdateViewRequestSettings": ".collections",
    "UpdateViewRequestType": ".collections",
    "UrlColumn": ".types",
    "Usage": ".types",
    "UsageTypes": ".types",
    "UserIdentity": ".types",
    "UserIdentityDetails": ".types",
    "UserOrganizationConfig": ".types",
    "ValidationError": ".types",
    "ValidationErrorLocItem": ".types",
    "ViewFilter": ".types",
    "ViewListResponse": ".types",
    "ViewListResponseDataItem": ".types",
    "ViewQueryInput": ".types",
    "ViewQueryOutput": ".types",
    "ViewResponse": ".types",
    "ViewResponseData": ".types",
    "ViewStateResponse": ".types",
    "ViewVisibility": ".types",
    "Workflow": ".types",
    "WorkflowActor": ".types",
    "WorkflowActorType": ".types",
    "WorkflowConfigInput": ".types",
    "WorkflowConfigOutput": ".types",
    "WorkflowExecute": ".types",
    "WorkflowHook": ".types",
    "WorkflowHookInput": ".types",
    "WorkflowLogsListLogsResponse": ".workflow_logs",
    "WorkflowNoteInput": ".types",
    "WorkflowNoteOutput": ".types",
    "WorkflowRun": ".types",
    "WorkflowRunCompleted": ".types",
    "WorkflowRunCompletedData": ".types",
    "WorkflowRunCompletedEnvironment": ".types",
    "WorkflowRunFailed": ".types",
    "WorkflowRunFailedData": ".types",
    "WorkflowRunFailedEnvironment": ".types",
    "WorkflowRunResponse": ".types",
    "WorkflowRunStarted": ".types",
    "WorkflowRunStartedData": ".types",
    "WorkflowRunStartedEnvironment": ".types",
    "WorkflowRunStateValue": ".types",
    "WorkflowRunStopReason": ".types",
    "WorkflowRunStreamResponse": ".types",
    "WorkflowTargetConfig": ".types",
    "WorkflowsRunRequestInputsValue": ".workflows",
    "WorkflowsRunStreamRequestInputsValue": ".workflows",
    "WorkflowsRunWithConfigResponse": ".workflows",
    "WorkflowsRunWithConfigResponseZero": ".workflows",
    "__version__": ".version",
    "collections": ".collections",
    "copilots": ".copilots",
    "documents": ".documents",
    "environments": ".environments",
    "integrations": ".integrations",
    "organizations": ".organizations",
    "revisions": ".revisions",
    "sources": ".sources",
    "syncs": ".syncs",
    "tables": ".tables",
    "triggers": ".triggers",
    "usage": ".usage",
    "workflow_logs": ".workflow_logs",
    "workflow_revisions": ".workflow_revisions",
    "workflows": ".workflows",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "ActionType",
    "ActivitySchema",
    "Actor",
    "ActorIdentity",
    "ActorIdentityId",
    "ActorIdentityType",
    "AgentHook",
    "AgentHookInput",
    "AgentRevision",
    "AgentRevisionModel",
    "AgentRevisionResponseStyle",
    "AgentRevisionToolConfigValue",
    "AgentTargetConfig",
    "AiAgent",
    "ApiKeyAuthType",
    "ApiKeyIdentity",
    "ApiKeyIdentityDetails",
    "AsyncScout",
    "AutomationHook",
    "AutomationHookInput",
    "AutomationTargetConfig",
    "BareInput",
    "BareOutput",
    "Baseline",
    "BatchCreateRequest",
    "BatchGenerateRequest",
    "Billing",
    "BillingCycle",
    "BillingCycles",
    "BillingLimits",
    "BillingUsage",
    "BlockConfigItemBoolean",
    "BlockConfigItemJson",
    "BlockConfigItemLlm",
    "BlockConfigItemNumber",
    "BlockConfigItemNumberDefaultValue",
    "BlockConfigItemNumberMaximumValue",
    "BlockConfigItemNumberMinimumValue",
    "BlockConfigItemNumberValue",
    "BlockConfigItemSelect",
    "BlockConfigItemTextLong",
    "BlockConfigItemTextLongValue",
    "BlockConfigItemTextShort",
    "BlockInput",
    "BlockInputBlockConfigItem",
    "BlockOutput",
    "BlockOutputBlockConfigItem",
    "BlockRun",
    "BlockRunCompleted",
    "BlockRunCompletedData",
    "BlockRunCompletedEnvironment",
    "BlockRunFailed",
    "BlockRunFailedData",
    "BlockRunFailedEnvironment",
    "BlockRunStarted",
    "BlockRunStartedData",
    "BlockRunStartedEnvironment",
    "BlockRunUsage",
    "BlockStateUpdated",
    "BlockStateUpdatedData",
    "BlockStateUpdatedDataUpdateType",
    "BlockStateUpdatedEnvironment",
    "BodyParseFileV2FilesParsePost",
    "BodyUploadFilesToDriveDriveFilesPost",
    "BodyUploadPrivateFilesInboxSessionIdFilesPost",
    "BodyUploadPulseFilesStreamPulseFilesStreamPost",
    "BodyUpsertAgentAgentsPost",
    "CancelResponse",
    "CardDisplayField",
    "Channel",
    "CheckBoxColumn",
    "Collection",
    "CollectionConfig",
    "CollectionDestination",
    "CollectionViewStateInput",
    "CollectionViewStateInputViewsValue",
    "CollectionViewStateOutput",
    "CollectionViewStateOutputViewsValue",
    "ColumnType",
    "ColumnTypeBase",
    "Condition",
    "ConditionField",
    "ConditionOperator",
    "ConnectIntegrationRequest",
    "ConnectIntegrationRequestAuthType",
    "Copilot",
    "CopilotConfig",
    "CopilotConfigCodeTheme",
    "CopilotConfigFabValue",
    "CopilotConfigMode",
    "CreateEntityRequest",
    "CreateIntegrationsResponse",
    "CreatePulseRequest",
    "CreatePulseResponse",
    "CreateTagResponse",
    "CreateViewRequestSettings",
    "CreateViewRequestType",
    "CronTriggerConfig",
    "CronTriggerConfigAction",
    "Custom",
    "DailyUsage",
    "DataType",
    "DateTimeColumn",
    "DefaultInput",
    "DefaultOutput",
    "DeleteHookResponse",
    "DeleteResponse",
    "DeleteTriggerResponse",
    "DeleteViewResponse",
    "Dependency",
    "DeterminedBillingLimits",
    "Dimensions",
    "Document",
    "DocumentCreatedBy",
    "DocumentDataValue",
    "DocumentLastUpdatedBy",
    "DocumentResponse",
    "DocumentsCreateRequestBody",
    "DocumentsCreateRequestBodyItemValue",
    "DocumentsCreateRequestBodyOneValue",
    "DocumentsCreateRequestBodyZeroValue",
    "DocumentsUpdateBatchRequestBody",
    "DocumentsUpdateBatchRequestBodyItemValue",
    "DocumentsUpdateBatchRequestBodyOneValue",
    "DocumentsUpdateBatchRequestBodyZeroValue",
    "DocumentsUpdateRequestValue",
    "EdgeUi",
    "EntityQueryRequest",
    "EntityResponse",
    "EntitySearchRequest",
    "EntitySearchRequestMode",
    "EntitySearchRequestReturnFormat",
    "Environment",
    "EnvironmentConfig",
    "EnvironmentDeploymentConfig",
    "EnvironmentDeploymentConfigRevisionLookup",
    "EnvironmentDeploymentDocument",
    "EventVersion",
    "ExecuteToolRequest",
    "ExecuteToolResponse",
    "ExecuteTriggerResponse",
    "Favor",
    "FavoriteItem",
    "FavoriteRef",
    "FieldMapping",
    "File",
    "FilesAttribute",
    "FilesResponse",
    "FilterOperator",
    "FilterType",
    "Flags",
    "FluentQueryRequest",
    "FluentQueryRequestWithItem",
    "FriendlyInvoice",
    "FriendlyPaymentMethods",
    "GenerateAiSuggestionRequest",
    "HookUpdate",
    "HooksListResponse",
    "Html2Text",
    "Http",
    "HttpValidationError",
    "Identity",
    "IdentityDetails",
    "IdentityTypes",
    "Integration",
    "IntegrationAuthType",
    "IntegrationConnection",
    "IntegrationConnectionAuthType",
    "IntegrationConnectionIntegrationType",
    "IntegrationWithConnections",
    "IntegrationWithConnectionsId",
    "Interval",
    "IntervalTypes",
    "Invoice",
    "InvoiceMeta",
    "InvoiceStatus",
    "JsonColumn",
    "KanbanViewInput",
    "KanbanViewOutput",
    "KanbanViewSettingsInput",
    "KanbanViewSettingsOutput",
    "LegacyIdentity",
    "LegacyIdentityDetails",
    "LineItem",
    "ListTagsResponse",
    "ListToolsResponse",
    "ListTriggersResponse",
    "Mapping",
    "MarkDownWithContext",
    "MarkdownColumn",
    "MarkdownSplitterConfig",
    "McpAuthType",
    "Me",
    "MeUpdate",
    "Mention",
    "MentionParticipant",
    "Message",
    "MessageChunk",
    "ModelProvider",
    "MultiPageCrawlerSettingsInput",
    "MultiPageCrawlerSettingsInputScraper",
    "MultiPageCrawlerSettingsInputTextExtractor",
    "MultiPageCrawlerSettingsOutput",
    "MultiPageCrawlerSettingsOutputScraper",
    "MultiPageCrawlerSettingsOutputTextExtractor",
    "MultiSelectColumn",
    "NodeUi",
    "Notification",
    "NotificationAction",
    "NotificationActionType",
    "NotificationSeverity",
    "NotificationType",
    "NotionFilterBy",
    "NotionFilterOptions",
    "NotionOAuthRequest",
    "NumberColumn",
    "NumberColumnDefault",
    "NumberColumnMaxValue",
    "NumberColumnMinValue",
    "OAuthAuthType",
    "Organization",
    "ParagraphSplitterConfig",
    "Participant",
    "ParticipantType",
    "PeopleColumn",
    "PlaceholderInput",
    "PlaceholderInputType",
    "PlaceholderOutput",
    "PlaceholderOutputType",
    "Plan",
    "PlanTypes",
    "Playwright",
    "PlaywrightWaitForLoadState",
    "Position",
    "Prompt",
    "PromptRole",
    "PublicCopilotConfig",
    "PublicCopilotConfigCodeTheme",
    "PublicCopilotConfigFabValue",
    "PublicCopilotConfigMode",
    "PublicCopilotResponse",
    "PulseFeedResponse",
    "PulseHook",
    "PulseHookInput",
    "PulseTargetConfig",
    "QueryBuilderRequest",
    "QueryBuilderRequestGroupByItem",
    "QueryBuilderRequestSortBy",
    "QueryBuilderRequestSortDirection",
    "QueryBuilderRequestTagMode",
    "QueryRequest",
    "QuerySort",
    "Readability",
    "RecursiveSplitterConfig",
    "RelationColumn",
    "RenameRequest",
    "RenameResponse",
    "ReqBody",
    "RequestBody",
    "Resource",
    "ResourceResourceType",
    "ResponseModelUsage",
    "Result",
    "RotateApiKeysRequest",
    "Rule",
    "RulesInput",
    "RulesOutput",
    "RunLog",
    "RunLogPagination",
    "Schedule",
    "SchemaResponse",
    "SchemasResponse",
    "Scout",
    "ScoutEnvironment",
    "ScoutHook",
    "ScoutHookConfigHttp",
    "ScoutHookEventDiscriminator",
    "ScoutHookEventDiscriminatorType",
    "ScoutHookEventTrigger",
    "ScoutHookResponse",
    "ScoutHookUpdate",
    "ScoutHookUpdateTriggeringEventsItem",
    "ScoutHooksResponse",
    "ScoutUser",
    "SearchRequest",
    "SearchRequestSearchType",
    "SelectColumn",
    "SelectOptionItem",
    "SentenceSplitterConfig",
    "ServiceInfo",
    "SinglePageCrawlerSettingsInput",
    "SinglePageCrawlerSettingsInputScraper",
    "SinglePageCrawlerSettingsInputTextExtractor",
    "SinglePageCrawlerSettingsOutput",
    "SinglePageCrawlerSettingsOutputScraper",
    "SinglePageCrawlerSettingsOutputTextExtractor",
    "SitemapCrawlerSettingsInput",
    "SitemapCrawlerSettingsInputScraper",
    "SitemapCrawlerSettingsInputTextExtractor",
    "SitemapCrawlerSettingsOutput",
    "SitemapCrawlerSettingsOutputScraper",
    "SitemapCrawlerSettingsOutputTextExtractor",
    "SlackEventResponse",
    "SlackMessageRequest",
    "SlackReactionRequest",
    "SlackTriggerConfigInput",
    "SlackTriggerConfigInputAction",
    "SlackTriggerConfigOutput",
    "SlackTriggerConfigOutputAction",
    "SlackUrlVerification",
    "SortDirection",
    "SourceArchetype",
    "SourceArchetypeIntegrationVersion",
    "SourceSync",
    "SourceSyncCrawlSettingsInput",
    "SourceSyncCrawlSettingsInputMode",
    "SourceSyncCrawlSettingsOutput",
    "SourceSyncCrawlSettingsOutputMode",
    "SourceSyncGoogleDriveSettings",
    "SourceSyncNotionSettingsInput",
    "SourceSyncNotionSettingsOutput",
    "SourceSyncPageCrawlSettingsInput",
    "SourceSyncPageCrawlSettingsInputMode",
    "SourceSyncPageCrawlSettingsOutput",
    "SourceSyncPageCrawlSettingsOutputMode",
    "SourceSyncSitemapSettingsInput",
    "SourceSyncSitemapSettingsInputMode",
    "SourceSyncSitemapSettingsOutput",
    "SourceSyncSitemapSettingsOutputMode",
    "SourceSyncWebsiteSettings",
    "SourceSyncWebsiteSettingsSplitter",
    "SrcAppHttpRoutesBillingBillingHourlyData",
    "SrcAppHttpRoutesBillingBillingHourlyResponse",
    "SrcAppHttpRoutesBillingChangeBillingPlanResponse",
    "SrcAppHttpRoutesBillingCreatePortalSessionData",
    "SrcAppHttpRoutesBillingCreatePortalSessionResponse",
    "SrcAppHttpRoutesBillingFreePlanUsageData",
    "SrcAppHttpRoutesBillingFreePlanUsageResponse",
    "SrcAppHttpRoutesBillingGetBillingData",
    "SrcAppHttpRoutesBillingGetBillingResponse",
    "SrcAppHttpRoutesBillingGetInfoGetInfoResponse",
    "SrcAppHttpRoutesBillingGetInvoicesData",
    "SrcAppHttpRoutesBillingGetInvoicesResponse",
    "SrcAppHttpRoutesBillingGetNotificationsResponse",
    "SrcAppHttpRoutesBillingRenewPlansData",
    "SrcAppHttpRoutesBillingRenewPlansResponse",
    "SrcAppHttpRoutesCollectionCreateCollectionResponse",
    "SrcAppHttpRoutesCollectionCreateSyncResponse",
    "SrcAppHttpRoutesCollectionCreateTableResponse",
    "SrcAppHttpRoutesCollectionDeleteCollectionResponse",
    "SrcAppHttpRoutesCollectionDeleteDocumentsResponse",
    "SrcAppHttpRoutesCollectionDeleteSyncResponse",
    "SrcAppHttpRoutesCollectionDeleteTableResponse",
    "SrcAppHttpRoutesCollectionGetCollectionResponse",
    "SrcAppHttpRoutesCollectionGetCollectionsResponse",
    "SrcAppHttpRoutesCollectionGetDocumentResponse",
    "SrcAppHttpRoutesCollectionGetDocumentsResponse",
    "SrcAppHttpRoutesCollectionGetSyncResponse",
    "SrcAppHttpRoutesCollectionGetSyncsResponse",
    "SrcAppHttpRoutesCollectionGetTableResponse",
    "SrcAppHttpRoutesCollectionGetTablesResponse",
    "SrcAppHttpRoutesCollectionListCollectionSyncsResponseModel",
    "SrcAppHttpRoutesCollectionListSourceArchetypesResponseModel",
    "SrcAppHttpRoutesCollectionParseFileResponse",
    "SrcAppHttpRoutesCollectionSyncTableResponse",
    "SrcAppHttpRoutesCollectionUpdateCollectionResponse",
    "SrcAppHttpRoutesCollectionUpdateDocumentResponse",
    "SrcAppHttpRoutesCollectionUpdateSyncResponse",
    "SrcAppHttpRoutesCollectionUpdateTableResponse",
    "SrcAppHttpRoutesDriveCreateDriveCrawlPayload",
    "SrcAppHttpRoutesDriveCreateDriveCrawlPayloadSourceSyncSettings",
    "SrcAppHttpRoutesDriveGrantAccessPayload",
    "SrcAppHttpRoutesDriveRevokeAccessPayload",
    "SrcAppHttpRoutesInboxHandleMessageIncomingMessage",
    "SrcAppHttpRoutesInboxHandleMessageIncomingMessageContent",
    "SrcAppHttpRoutesInboxHandleMessageIncomingMessageContentType",
    "SrcAppHttpRoutesInboxHandleMessageInteractionRequest",
    "SrcAppHttpRoutesInboxHandleMessageInteractionRequestParticipantsItem",
    "SrcAppHttpRoutesIntegrationMcpConnectMcpPayload",
    "SrcAppHttpRoutesIntegrationMcpExchangeMcpAuthPayload",
    "SrcAppHttpRoutesOnboardingHandleGetMeResponse",
    "SrcAppHttpRoutesOnboardingHandleUpdateMeResponse",
    "SrcAppHttpRoutesRootGetInfoResponse",
    "SrcAppHttpRoutesTagsCreateTagPayload",
    "SrcAppHttpRoutesTagsUpdateTagPayload",
    "SrcAppHttpRoutesTriggerCreateTriggerResponse",
    "SrcAppHttpRoutesWorldInteractIncomingMessage",
    "SrcAppHttpRoutesWorldInteractIncomingMessageContent",
    "SrcAppHttpRoutesWorldInteractIncomingMessageContentItem",
    "SrcAppHttpRoutesWorldInteractInteractionRequest",
    "SrcHandlersCreateCopilotResponse",
    "SrcHandlersCreateWorkflowResponse",
    "SrcHandlersCreateWorkflowRevisionResponse",
    "SrcHandlersDeleteCopilotResponse",
    "SrcHandlersDeleteWorkflowResponse",
    "SrcHandlersDeleteWorkflowRevisionResponse",
    "SrcHandlersGetCopilotResponse",
    "SrcHandlersGetWorkflowEnvironmentsResponse",
    "SrcHandlersGetWorkflowResponse",
    "SrcHandlersListCopilotsResponse",
    "SrcHandlersListWorkflowRevisionsResponse",
    "SrcHandlersListWorkflowsResponse",
    "SrcHandlersPromoteWorkflowRevisionResponse",
    "SrcHandlersUpdateCopilotResponse",
    "SrcHandlersUpdateWorkflowEnvironmentResponse",
    "SrcHandlersUpdateWorkflowResponse",
    "SrcHandlersUpdateWorkflowRevisionResponse",
    "SrcHandlersWorkflowsExecuteWithConfigReqBodyInputsValue",
    "StoreResponse",
    "StripeProvider",
    "StripeProviderMeta",
    "Subscription",
    "Sync",
    "SyncConfigInput",
    "SyncConfigInputSourceSettings",
    "SyncConfigOutput",
    "SyncConfigOutputSourceSettings",
    "Table",
    "TableConfigInputSchemaItem",
    "TableConfigOutput",
    "TableConfigOutputSchemaItem",
    "TableDataSchemaItem",
    "TableViewInput",
    "TableViewOutput",
    "TableViewSettingsInput",
    "TableViewSettingsInputRowHeight",
    "TableViewSettingsOutput",
    "TableViewSettingsOutputRowHeight",
    "Tag",
    "TagsResponse",
    "TextExtractor",
    "TextExtractorConfig",
    "TextLongColumn",
    "TextShortColumn",
    "Tool",
    "ToolConfigResource",
    "ToolConfigResourceType",
    "ToolDetails",
    "ToolsData",
    "ToolsResponse",
    "TrafilaturaInput",
    "TrafilaturaInputTrafilaturaType",
    "TrafilaturaOutput",
    "TrafilaturaOutputTrafilaturaType",
    "Trigger",
    "TriggerStatus",
    "TriggerTriggerConfig",
    "TriggersCreateRequest",
    "TriggersExecuteSlackResponse",
    "TriggersUpdateRequest",
    "TypescriptAutomationConfig",
    "Units",
    "UnprocessableEntityError",
    "UpdateCronAuthResponse",
    "UpdateEntityRequest",
    "UpdateQuestionnaireFilesRequest",
    "UpdateTagResponse",
    "UpdateTagsRequest",
    "UpdateTriggerResponse",
    "UpdateViewRequestSettings",
    "UpdateViewRequestType",
    "UrlColumn",
    "Usage",
    "UsageTypes",
    "UserIdentity",
    "UserIdentityDetails",
    "UserOrganizationConfig",
    "ValidationError",
    "ValidationErrorLocItem",
    "ViewFilter",
    "ViewListResponse",
    "ViewListResponseDataItem",
    "ViewQueryInput",
    "ViewQueryOutput",
    "ViewResponse",
    "ViewResponseData",
    "ViewStateResponse",
    "ViewVisibility",
    "Workflow",
    "WorkflowActor",
    "WorkflowActorType",
    "WorkflowConfigInput",
    "WorkflowConfigOutput",
    "WorkflowExecute",
    "WorkflowHook",
    "WorkflowHookInput",
    "WorkflowLogsListLogsResponse",
    "WorkflowNoteInput",
    "WorkflowNoteOutput",
    "WorkflowRun",
    "WorkflowRunCompleted",
    "WorkflowRunCompletedData",
    "WorkflowRunCompletedEnvironment",
    "WorkflowRunFailed",
    "WorkflowRunFailedData",
    "WorkflowRunFailedEnvironment",
    "WorkflowRunResponse",
    "WorkflowRunStarted",
    "WorkflowRunStartedData",
    "WorkflowRunStartedEnvironment",
    "WorkflowRunStateValue",
    "WorkflowRunStopReason",
    "WorkflowRunStreamResponse",
    "WorkflowTargetConfig",
    "WorkflowsRunRequestInputsValue",
    "WorkflowsRunStreamRequestInputsValue",
    "WorkflowsRunWithConfigResponse",
    "WorkflowsRunWithConfigResponseZero",
    "__version__",
    "collections",
    "copilots",
    "documents",
    "environments",
    "integrations",
    "organizations",
    "revisions",
    "sources",
    "syncs",
    "tables",
    "triggers",
    "usage",
    "workflow_logs",
    "workflow_revisions",
    "workflows",
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class CreatePulseRequest(UncheckedBaseModel):
    action: typing.Optional[str] = None
    description: str
    agents: typing.List[typing.Dict[str, typing.Optional[typing.Any]]]
    objects: typing.Optional[typing.List[typing.Dict[str, typing.Optional[typing.Any]]]] = None
    context: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = None
    tags: typing.Optional[typing.List[str]] = None
    visibility: typing.Optional[str] = None
    duration_minutes: typing.Optional[float] = None
    content: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = None
    text: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class CreateEntityRequest(UncheckedBaseModel):
    """
    Create request - just type and data
    """

    type: str = pydantic.Field()
    """
    Entity type (e.g., 'todo', 'note', 'task')
    """

    data: typing.Dict[str, typing.Optional[typing.Any]] = pydantic.Field()
    """
    Entity data
    """

    tags: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Optional tags
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .single_page_crawler_settings_output import SinglePageCrawlerSettingsOutput
from .source_sync_page_crawl_settings_output_mode import SourceSyncPageCrawlSettingsOutputMode


class SourceSyncPageCrawlSettingsOutput(UncheckedBaseModel):
    source_archetype_id: typing.Literal["com.scoutos.page_crawl"] = "com.scoutos.page_crawl"
    start_urls: str = pydantic.Field()
    """
    The starting URL for the crawl process.
    """

    crawler_settings: typing.Optional[SinglePageCrawlerSettingsOutput] = None
    mode: typing.Optional[SourceSyncPageCrawlSettingsOutputMode] = pydantic.Field(default=None)
    """
    Merge: upsert documents keying off site url. Replace: merge and remove stale documents.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .legacy_identity import LegacyIdentity
from .sync_config_output import SyncConfigOutput


class Sync(UncheckedBaseModel):
    sync_config: SyncConfigOutput
    sync_id: str
    trigger_id: typing.Optional[str] = None
    last_updated_at: dt.datetime
    created_at: dt.datetime
    created_by: LegacyIdentity
    last_updated_by: LegacyIdentity

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .card_display_field import CardDisplayField
from .view_filter import ViewFilter


class KanbanViewSettingsInput(UncheckedBaseModel):
    column_visibility: typing.Optional[typing.Dict[str, bool]] = None
    column_order: typing.Optional[typing.List[str]] = None
    column_widths: typing.Optional[typing.Dict[str, int]] = None
    type: typing.Literal["kanban"] = "kanban"
    grouping_column: str
    group_visibility: typing.Optional[typing.Dict[str, bool]] = None
    group_order: typing.Optional[typing.List[str]] = None
    card_display_fields: typing.Optional[typing.List[CardDisplayField]] = None
    card_compact_mode: typing.Optional[bool] = None
    card_image_field: typing.Optional[str] = None
    filters: typing.Optional[typing.List[ViewFilter]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.http_response import AsyncHttpResponse, HttpResponse
from ..core.jsonable_encoder import jsonable_encoder
from ..core.request_options import RequestOptions
from ..core.serialization import convert_and_respect_annotation_metadata
from ..core.unchecked_base_model import construct_type
from ..errors.unprocessable_entity_error import UnprocessableEntityError
from ..types.action_type import ActionType
from ..types.delete_trigger_response import DeleteTriggerResponse
from ..types.execute_trigger_response import ExecuteTriggerResponse
from ..types.http_validation_error import HttpValidationError
from ..types.list_triggers_response import ListTriggersResponse
from ..types.src_app_http_routes_trigger_create_trigger_response import SrcAppHttpRoutesTriggerCreateTriggerResponse
from ..types.update_cron_auth_response import UpdateCronAuthResponse
from ..types.update_trigger_response import UpdateTriggerResponse
from .types.triggers_create_request import TriggersCreateRequest
from .types.triggers_execute_slack_response import TriggersExecuteSlackResponse
from .types.triggers_update_request import TriggersUpdateRequest

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawTriggersClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def list(
        self,
        *,
        action_type: typing.Optional[ActionType] = None,
        workflow_id: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[ListTriggersResponse]:
        """
        All apis and effects are injected into every endpoint
        via request.context. The request_context() utility can be used
        to get Intellisense type-completion

        Parameters
        ----------
        action_type : typing.Optional[ActionType]
            Filter by action type

        workflow_id : typing.Optional[str]
            Filter by workflow ID

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ListTriggersResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "v2/triggers",
            method="GET",
            params={
                "action_type": action_type,
                "workflow_id": workflow_id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ListTriggersResponse,
                    construct_type(
                        type_=ListTriggersResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def create(
        self, *, request: TriggersCreateRequest, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[SrcAppHttpRoutesTriggerCreateTriggerResponse]:
        """
        Parameters
        ----------
        request : TriggersCreateRequest

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[SrcAppHttpRoutesTriggerCreateTriggerResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "v2/triggers",
            method="POST",
            json=convert_and_respect_annotation_metadata(
                object_=request, annotation=TriggersCreateRequest, direction="write"
            ),
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    SrcAppHttpRoutesTriggerCreateTriggerResponse,
                    construct_type(
                        type_=SrcAppHttpRoutesTriggerCreateTriggerResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def update(
        self,
        trigger_id: str,
        *,
        request: TriggersUpdateRequest,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[UpdateTriggerResponse]:
        """
        Parameters
        ----------
        trigger_id : str

        request : TriggersUpdateRequest

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[UpdateTriggerResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v2/triggers/{jsonable_encoder(trigger_id)}",
            method="PUT",
            json=convert_and_respect_annotation_metadata(
                object_=request, annotation=TriggersUpdateRequest, direction="write"
            ),
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    UpdateTriggerResponse,
                    construct_type(
                        type_=UpdateTriggerResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def delete(
        self, trigger_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[DeleteTriggerResponse]:
        """
        Parameters
        ----------
        trigger_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[DeleteTriggerResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v2/triggers/{jsonable_encoder(trigger_id)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    DeleteTriggerResponse,
                    construct_type(
                        type_=DeleteTriggerResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def execute_slack(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[TriggersExecuteSlackResponse]:
        """
        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[TriggersExecuteSlackResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "v2/triggers/slack/execute",
            method="POST",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    TriggersExecuteSlackResponse,
                    construct_type(
                        type_=TriggersExecuteSlackResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def execute_cron(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[ExecuteTriggerResponse]:
        """
        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ExecuteTriggerResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "v2/triggers/cron/execute",
            method="POST",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ExecuteTriggerResponse,
                    construct_type(
                        type_=ExecuteTriggerResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def update_cron_auth_headers(
        self,
        *,
        dry_run: typing.Optional[bool] = None,
        test_org_id: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[UpdateCronAuthResponse]:
        """
        Update Cloud Scheduler job Authorization headers for organizations.
        Lists all Cloud Scheduler jobs and updates those matching the trigger pattern.

        Args:
            dry_run: If True, only shows what would be updated without making changes
            test_org_id: If provided, only processes jobs for this specific organization ID

        Only accessible to Scout internal organizations for security.

        Parameters
        ----------
        dry_run : typing.Optional[bool]

        test_org_id : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[UpdateCronAuthResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "v2/triggers/cron/update-auth-headers",
            method="POST",
            params={
                "dry_run": dry_run,
                "test_org_id": test_org_id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    UpdateCronAuthResponse,
                    construct_type(
                        type_=UpdateCronAuthResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawTriggersClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def list(
        self,
        *,
        action_type: typing.Optional[ActionType] = None,
        workflow_id: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[ListTriggersResponse]:
        """
        All apis and effects are injected into every endpoint
        via request.context. The request_context() utility can be used
        to get Intellisense type-completion

        Parameters
        ----------
        action_type : typing.Optional[ActionType]
            Filter by action type

        workflow_id : typing.Optional[str]
            Filter by workflow ID

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ListTriggersResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v2/triggers",
            method="GET",
            params={
                "action_type": action_type,
                "workflow_id": workflow_id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ListTriggersResponse,
                    construct_type(
                        type_=ListTriggersResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def create(
        self, *, request: TriggersCreateRequest, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[SrcAppHttpRoutesTriggerCreateTriggerResponse]:
        """
        Parameters
        ----------
        request : TriggersCreateRequest

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[SrcAppHttpRoutesTriggerCreateTriggerResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v2/triggers",
            method="POST",
            json=convert_and_respect_annotation_metadata(
                object_=request, annotation=TriggersCreateRequest, direction="write"
            ),
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    SrcAppHttpRoutesTriggerCreateTriggerResponse,
                    construct_type(
                        type_=SrcAppHttpRoutesTriggerCreateTriggerResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def update(
        self,
        trigger_id: str,
        *,
        request: TriggersUpdateRequest,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[UpdateTriggerResponse]:
        """
        Parameters
        ----------
        trigger_id : str

        request : TriggersUpdateRequest

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[UpdateTriggerResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v2/triggers/{jsonable_encoder(trigger_id)}",
            method="PUT",
            json=convert_and_respect_annotation_metadata(
                object_=request, annotation=TriggersUpdateRequest, direction="write"
            ),
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    UpdateTriggerResponse,
                    construct_type(
                        type_=UpdateTriggerResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def delete(
        self, trigger_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[DeleteTriggerResponse]:
        """
        Parameters
        ----------
        trigger_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[DeleteTriggerResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v2/triggers/{jsonable_encoder(trigger_id)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    DeleteTriggerResponse,
                    construct_type(
                        type_=DeleteTriggerResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def execute_slack(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[TriggersExecuteSlackResponse]:
        """
        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[TriggersExecuteSlackResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v2/triggers/slack/execute",
            method="POST",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    TriggersExecuteSlackResponse,
                    construct_type(
                        type_=TriggersExecuteSlackResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def execute_cron(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[ExecuteTriggerResponse]:
        """
        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ExecuteTriggerResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v2/triggers/cron/execute",
            method="POST",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ExecuteTriggerResponse,
                    construct_type(
                        type_=ExecuteTriggerResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def update_cron_auth_headers(
        self,
        *,
        dry_run: typing.Optional[bool] = None,
        test_org_id: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[UpdateCronAuthResponse]:
        """
        Update Cloud Scheduler job Authorization headers for organizations.
        Lists all Cloud Scheduler jobs and updates those matching the trigger pattern.

        Args:
            dry_run: If True, only shows what would be updated without making changes
            test_org_id: If provided, only processes jobs for this specific organization ID

        Only accessible to Scout internal organizations for security.

        Parameters
        ----------
        dry_run : typing.Optional[bool]

        test_org_id : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[UpdateCronAuthResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v2/triggers/cron/update-auth-headers",
            method="POST",
            params={
                "dry_run": dry_run,
                "test_org_id": test_org_id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    UpdateCronAuthResponse,
                    construct_type(
                        type_=UpdateCronAuthResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import typing

from .kanban_view_input import KanbanViewInput
from .table_view_input import TableViewInput

CollectionViewStateInputViewsValue = typing.Union[KanbanViewInput, TableViewInput]



# This file was auto-generated by Fern from our API Definition.

import typing

from .documents_update_batch_request_body_item_value import DocumentsUpdateBatchRequestBodyItemValue
from .documents_update_batch_request_body_one_value import DocumentsUpdateBatchRequestBodyOneValue
from .documents_update_batch_request_body_zero_value import DocumentsUpdateBatchRequestBodyZeroValue

DocumentsUpdateBatchRequestBody = typing.Union[
    typing.Dict[str, DocumentsUpdateBatchRequestBodyZeroValue],
    typing.Dict[str, typing.Optional[DocumentsUpdateBatchRequestBodyOneValue]],
    typing.List[typing.Dict[str, DocumentsUpdateBatchRequestBodyItemValue]],
    typing.List[typing.Dict[str, typing.Optional[DocumentsUpdateBatchRequestBodyItemValue]]],
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .public_copilot_config_code_theme import PublicCopilotConfigCodeTheme
from .public_copilot_config_fab_value import PublicCopilotConfigFabValue
from .public_copilot_config_mode import PublicCopilotConfigMode


class PublicCopilotConfig(UncheckedBaseModel):
    """
    Public copilot configuration without sensitive fields.
    """

    workflow_id: typing.Optional[str] = None
    img_url: typing.Optional[str] = None
    display_name: typing.Optional[str] = None
    mode: typing.Optional[PublicCopilotConfigMode] = None
    code_theme: typing.Optional[PublicCopilotConfigCodeTheme] = None
    colors: typing.Optional[typing.Dict[str, str]] = None
    fab: typing.Optional[typing.Dict[str, typing.Optional[PublicCopilotConfigFabValue]]] = None
    loading_text: typing.Optional[str] = None
    message_placeholder: typing.Optional[str] = None
    initial_activity: typing.Optional[typing.List[typing.Optional[typing.Any]]] = None
    powered_by: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import os
import typing

import httpx
from .core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .environment import ScoutEnvironment

if typing.TYPE_CHECKING:
    from .collections.client import AsyncCollectionsClient, CollectionsClient
    from .copilots.client import AsyncCopilotsClient, CopilotsClient
    from .documents.client import AsyncDocumentsClient, DocumentsClient
    from .environments.client import AsyncEnvironmentsClient, EnvironmentsClient
    from .integrations.client import AsyncIntegrationsClient, IntegrationsClient
    from .organizations.client import AsyncOrganizationsClient, OrganizationsClient
    from .revisions.client import AsyncRevisionsClient, RevisionsClient
    from .sources.client import AsyncSourcesClient, SourcesClient
    from .syncs.client import AsyncSyncsClient, SyncsClient
    from .tables.client import AsyncTablesClient, TablesClient
    from .triggers.client import AsyncTriggersClient, TriggersClient
    from .usage.client import AsyncUsageClient, UsageClient
    from .workflow_logs.client import AsyncWorkflowLogsClient, WorkflowLogsClient
    from .workflow_revisions.client import AsyncWorkflowRevisionsClient, WorkflowRevisionsClient
    from .workflows.client import AsyncWorkflowsClient, WorkflowsClient


class Scout:
    """
    Use this class to access the different functions within the SDK. You can instantiate any number of clients with different configuration that will propagate to these functions.

    Parameters
    ----------
    base_url : typing.Optional[str]
        The base url to use for requests from the client.

    environment : ScoutEnvironment
        The environment to use for requests from the client. from .environment import ScoutEnvironment



        Defaults to ScoutEnvironment.PROD



    api_key : typing.Optional[typing.Union[str, typing.Callable[[], str]]]
    headers : typing.Optional[typing.Dict[str, str]]
        Additional headers to send with every request.

    timeout : typing.Optional[float]
        The timeout to be used, in seconds, for requests. By default the timeout is 60 seconds, unless a custom httpx client is used, in which case this default is not enforced.

    follow_redirects : typing.Optional[bool]
        Whether the default httpx client follows redirects or not, this is irrelevant if a custom httpx client is passed in.

    httpx_client : typing.Optional[httpx.Client]
        The httpx client to use for making requests, a preconfigured client is used by default, however this is useful should you want to pass in any custom httpx configuration.

    Examples
    --------
    from scoutos import Scout

    client = Scout(
        api_key="YOUR_API_KEY",
    )
    """

    def __init__(
        self,
        *,
        base_url: typing.Optional[str] = None,
        environment: ScoutEnvironment = ScoutEnvironment.PROD,
        api_key: typing.Optional[typing.Union[str, typing.Callable[[], str]]] = os.getenv("SCOUT_API_KEY"),
        headers: typing.Optional[typing.Dict[str, str]] = None,
        timeout: typing.Optional[float] = None,
        follow_redirects: typing.Optional[bool] = True,
        httpx_client: typing.Optional[httpx.Client] = None,
    ):
        _defaulted_timeout = (
            timeout if timeout is not None else 60 if httpx_client is None else httpx_client.timeout.read
        )
        self._client_wrapper = SyncClientWrapper(
            base_url=_get_base_url(base_url=base_url, environment=environment),
            api_key=api_key,
            headers=headers,
            httpx_client=httpx_client
            if httpx_client is not None
            else httpx.Client(timeout=_defaulted_timeout, follow_redirects=follow_redirects)
            if follow_redirects is not None
            else httpx.Client(timeout=_defaulted_timeout),
            timeout=_defaulted_timeout,
        )
        self._workflows: typing.Optional[WorkflowsClient] = None
        self._workflow_revisions: typing.Optional[WorkflowRevisionsClient] = None
        self._revisions: typing.Optional[RevisionsClient] = None
        self._environments: typing.Optional[EnvironmentsClient] = None
        self._usage: typing.Optional[UsageClient] = None
        self._workflow_logs: typing.Optional[WorkflowLogsClient] = None
        self._copilots: typing.Optional[CopilotsClient] = None
        self._triggers: typing.Optional[TriggersClient] = None
        self._integrations: typing.Optional[IntegrationsClient] = None
        self._organizations: typing.Optional[OrganizationsClient] = None
        self._collections: typing.Optional[CollectionsClient] = None
        self._tables: typing.Optional[TablesClient] = None
        self._documents: typing.Optional[DocumentsClient] = None
        self._sources: typing.Optional[SourcesClient] = None
        self._syncs: typing.Optional[SyncsClient] = None

    @property
    def workflows(self):
        if self._workflows is None:
            from .workflows.client import WorkflowsClient  # noqa: E402

            self._workflows = WorkflowsClient(client_wrapper=self._client_wrapper)
        return self._workflows

    @property
    def workflow_revisions(self):
        if self._workflow_revisions is None:
            from .workflow_revisions.client import WorkflowRevisionsClient  # noqa: E402

            self._workflow_revisions = WorkflowRevisionsClient(client_wrapper=self._client_wrapper)
        return self._workflow_revisions

    @property
    def revisions(self):
        if self._revisions is None:
            from .revisions.client import RevisionsClient  # noqa: E402

            self._revisions = RevisionsClient(client_wrapper=self._client_wrapper)
        return self._revisions

    @property
    def environments(self):
        if self._environments is None:
            from .environments.client import EnvironmentsClient  # noqa: E402

            self._environments = EnvironmentsClient(client_wrapper=self._client_wrapper)
        return self._environments

    @property
    def usage(self):
        if self._usage is None:
            from .usage.client import UsageClient  # noqa: E402

            self._usage = UsageClient(client_wrapper=self._client_wrapper)
        return self._usage

    @property
    def workflow_logs(self):
        if self._workflow_logs is None:
            from .workflow_logs.client import WorkflowLogsClient  # noqa: E402

            self._workflow_logs = WorkflowLogsClient(client_wrapper=self._client_wrapper)
        return self._workflow_logs

    @property
    def copilots(self):
        if self._copilots is None:
            from .copilots.client import CopilotsClient  # noqa: E402

            self._copilots = CopilotsClient(client_wrapper=self._client_wrapper)
        return self._copilots

    @property
    def triggers(self):
        if self._triggers is None:
            from .triggers.client import TriggersClient  # noqa: E402

            self._triggers = TriggersClient(client_wrapper=self._client_wrapper)
        return self._triggers

    @property
    def integrations(self):
        if self._integrations is None:
            from .integrations.client import IntegrationsClient  # noqa: E402

            self._integrations = IntegrationsClient(client_wrapper=self._client_wrapper)
        return self._integrations

    @property
    def organizations(self):
        if self._organizations is None:
            from .organizations.client import OrganizationsClient  # noqa: E402

            self._organizations = OrganizationsClient(client_wrapper=self._client_wrapper)
        return self._organizations

    @property
    def collections(self):
        if self._collections is None:
            from .collections.client import CollectionsClient  # noqa: E402

            self._collections = CollectionsClient(client_wrapper=self._client_wrapper)
        return self._collections

    @property
    def tables(self):
        if self._tables is None:
            from .tables.client import TablesClient  # noqa: E402

            self._tables = TablesClient(client_wrapper=self._client_wrapper)
        return self._tables

    @property
    def documents(self):
        if self._documents is None:
            from .documents.client import DocumentsClient  # noqa: E402

            self._documents = DocumentsClient(client_wrapper=self._client_wrapper)
        return self._documents

    @property
    def sources(self):
        if self._sources is None:
            from .sources.client import SourcesClient  # noqa: E402

            self._sources = SourcesClient(client_wrapper=self._client_wrapper)
        return self._sources

    @property
    def syncs(self):
        if self._syncs is None:
            from .syncs.client import SyncsClient  # noqa: E402

            self._syncs = SyncsClient(client_wrapper=self._client_wrapper)
        return self._syncs


class AsyncScout:
    """
    Use this class to access the different functions within the SDK. You can instantiate any number of clients with different configuration that will propagate to these functions.

    Parameters
    ----------
    base_url : typing.Optional[str]
        The base url to use for requests from the client.

    environment : ScoutEnvironment
        The environment to use for requests from the client. from .environment import ScoutEnvironment



        Defaults to ScoutEnvironment.PROD



    api_key : typing.Optional[typing.Union[str, typing.Callable[[], str]]]
    headers : typing.Optional[typing.Dict[str, str]]
        Additional headers to send with every request.

    timeout : typing.Optional[float]
        The timeout to be used, in seconds, for requests. By default the timeout is 60 seconds, unless a custom httpx client is used, in which case this default is not enforced.

    follow_redirects : typing.Optional[bool]
        Whether the default httpx client follows redirects or not, this is irrelevant if a custom httpx client is passed in.

    httpx_client : typing.Optional[httpx.AsyncClient]
        The httpx client to use for making requests, a preconfigured client is used by default, however this is useful should you want to pass in any custom httpx configuration.

    Examples
    --------
    from scoutos import AsyncScout

    client = AsyncScout(
        api_key="YOUR_API_KEY",
    )
    """

    def __init__(
        self,
        *,
        base_url: typing.Optional[str] = None,
        environment: ScoutEnvironment = ScoutEnvironment.PROD,
        api_key: typing.Optional[typing.Union[str, typing.Callable[[], str]]] = os.getenv("SCOUT_API_KEY"),
        headers: typing.Optional[typing.Dict[str, str]] = None,
        timeout: typing.Optional[float] = None,
        follow_redirects: typing.Optional[bool] = True,
        httpx_client: typing.Optional[httpx.AsyncClient] = None,
    ):
        _defaulted_timeout = (
            timeout if timeout is not None else 60 if httpx_client is None else httpx_client.timeout.read
        )
        self._client_wrapper = AsyncClientWrapper(
            base_url=_get_base_url(base_url=base_url, environment=environment),
            api_key=api_key,
            headers=headers,
            httpx_client=httpx_client
            if httpx_client is not None
            else httpx.AsyncClient(timeout=_defaulted_timeout, follow_redirects=follow_redirects)
            if follow_redirects is not None
            else httpx.AsyncClient(timeout=_defaulted_timeout),
            timeout=_defaulted_timeout,
        )
        self._workflows: typing.Optional[AsyncWorkflowsClient] = None
        self._workflow_revisions: typing.Optional[AsyncWorkflowRevisionsClient] = None
        self._revisions: typing.Optional[AsyncRevisionsClient] = None
        self._environments: typing.Optional[AsyncEnvironmentsClient] = None
        self._usage: typing.Optional[AsyncUsageClient] = None
        self._workflow_logs: typing.Optional[AsyncWorkflowLogsClient] = None
        self._copilots: typing.Optional[AsyncCopilotsClient] = None
        self._triggers: typing.Optional[AsyncTriggersClient] = None
        self._integrations: typing.Optional[AsyncIntegrationsClient] = None
        self._organizations: typing.Optional[AsyncOrganizationsClient] = None
        self._collections: typing.Optional[AsyncCollectionsClient] = None
        self._tables: typing.Optional[AsyncTablesClient] = None
        self._documents: typing.Optional[AsyncDocumentsClient] = None
        self._sources: typing.Optional[AsyncSourcesClient] = None
        self._syncs: typing.Optional[AsyncSyncsClient] = None

    @property
    def workflows(self):
        if self._workflows is None:
            from .workflows.client import AsyncWorkflowsClient  # noqa: E402

            self._workflows = AsyncWorkflowsClient(client_wrapper=self._client_wrapper)
        return self._workflows

    @property
    def workflow_revisions(self):
        if self._workflow_revisions is None:
            from .workflow_revisions.client import AsyncWorkflowRevisionsClient  # noqa: E402

            self._workflow_revisions = AsyncWorkflowRevisionsClient(client_wrapper=self._client_wrapper)
        return self._workflow_revisions

    @property
    def revisions(self):
        if self._revisions is None:
            from .revisions.client import AsyncRevisionsClient  # noqa: E402

            self._revisions = AsyncRevisionsClient(client_wrapper=self._client_wrapper)
        return self._revisions

    @property
    def environments(self):
        if self._environments is None:
            from .environments.client import AsyncEnvironmentsClient  # noqa: E402

            self._environments = AsyncEnvironmentsClient(client_wrapper=self._client_wrapper)
        return self._environments

    @property
    def usage(self):
        if self._usage is None:
            from .usage.client import AsyncUsageClient  # noqa: E402

            self._usage = AsyncUsageClient(client_wrapper=self._client_wrapper)
        return self._usage

    @property
    def workflow_logs(self):
        if self._workflow_logs is None:
            from .workflow_logs.client import AsyncWorkflowLogsClient  # noqa: E402

            self._workflow_logs = AsyncWorkflowLogsClient(client_wrapper=self._client_wrapper)
        return self._workflow_logs

    @property
    def copilots(self):
        if self._copilots is None:
            from .copilots.client import AsyncCopilotsClient  # noqa: E402

            self._copilots = AsyncCopilotsClient(client_wrapper=self._client_wrapper)
        return self._copilots

    @property
    def triggers(self):
        if self._triggers is None:
            from .triggers.client import AsyncTriggersClient  # noqa: E402

            self._triggers = AsyncTriggersClient(client_wrapper=self._client_wrapper)
        return self._triggers

    @property
    def integrations(self):
        if self._integrations is None:
            from .integrations.client import AsyncIntegrationsClient  # noqa: E402

            self._integrations = AsyncIntegrationsClient(client_wrapper=self._client_wrapper)
        return self._integrations

    @property
    def organizations(self):
        if self._organizations is None:
            from .organizations.client import AsyncOrganizationsClient  # noqa: E402

            self._organizations = AsyncOrganizationsClient(client_wrapper=self._client_wrapper)
        return self._organizations

    @property
    def collections(self):
        if self._collections is None:
            from .collections.client import AsyncCollectionsClient  # noqa: E402

            self._collections = AsyncCollectionsClient(client_wrapper=self._client_wrapper)
        return self._collections

    @property
    def tables(self):
        if self._tables is None:
            from .tables.client import AsyncTablesClient  # noqa: E402

            self._tables = AsyncTablesClient(client_wrapper=self._client_wrapper)
        return self._tables

    @property
    def documents(self):
        if self._documents is None:
            from .documents.client import AsyncDocumentsClient  # noqa: E402

            self._documents = AsyncDocumentsClient(client_wrapper=self._client_wrapper)
        return self._documents

    @property
    def sources(self):
        if self._sources is None:
            from .sources.client import AsyncSourcesClient  # noqa: E402

            self._sources = AsyncSourcesClient(client_wrapper=self._client_wrapper)
        return self._sources

    @property
    def syncs(self):
        if self._syncs is None:
            from .syncs.client import AsyncSyncsClient  # noqa: E402

            self._syncs = AsyncSyncsClient(client_wrapper=self._client_wrapper)
        return self._syncs


def _get_base_url(*, base_url: typing.Optional[str] = None, environment: ScoutEnvironment) -> str:
    if base_url is not None:
        return base_url
    elif environment is not None:
        return environment.value
    else:
        raise Exception("Please pass in either base_url or environment to construct the client")



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .billing_cycles import BillingCycles
from .determined_billing_limits import DeterminedBillingLimits
from .friendly_payment_methods import FriendlyPaymentMethods
from .invoice import Invoice
from .subscription import Subscription


class SrcAppHttpRoutesBillingGetBillingData(UncheckedBaseModel):
    payment_methods: typing.List[FriendlyPaymentMethods]
    has_payment_method: bool
    has_default_payment_method: bool
    needs_billing_email: bool
    active_plan: typing.Optional[Subscription] = None
    future_plans: typing.List[Subscription]
    billing_cycles: typing.Optional[BillingCycles] = None
    failed_invoices: typing.List[Invoice]
    has_failed_payment: bool
    workflow_invocations: int
    billing_limits: DeterminedBillingLimits
    agent_interactions: int

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

QueryBuilderRequestGroupByItem = typing.Union[
    typing.Literal["time_hour", "time_day", "time_week", "agent_type", "action_type", "tag_prefix"], typing.Any
]



# This file was auto-generated by Fern from our API Definition.

import typing

from .kanban_view_output import KanbanViewOutput
from .table_view_output import TableViewOutput

ViewListResponseDataItem = typing.Union[KanbanViewOutput, TableViewOutput]



# This file was auto-generated by Fern from our API Definition.

import typing

ConditionField = typing.Union[
    typing.Literal[
        "channel_id",
        "team_id",
        "user_id",
        "thread_id",
        "user_message",
        "is_first_message_in_thread",
        "channel_name",
        "bot_is_mentioned",
        "is_bot_message",
    ],
    typing.Any,
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class FieldMapping(UncheckedBaseModel):
    """
    Mapping from webhook data to workflow input field.
    """

    source_path: str = pydantic.Field()
    """
    JSONPath expression to extract value (e.g., '$.customer.email', '$.items[0].id', '$.headers.X-User-ID', '$[*].name')
    """

    target_field_id: str = pydantic.Field()
    """
    The workflow input field ID to map to
    """

    transform: typing.Optional[str] = pydantic.Field(default=None)
    """
    Optional transform to apply (future: 'uppercase', 'parse_json', etc.)
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
